@@ -1,8 +1,10 @@
 {-# LANGUAGE OverloadedStrings #-}
+
 -- | File finding utiliites for Shelly
 -- The basic 'find' takes a dir and gives back a list of files.
 -- If you don't just want a list, use the folding variants like 'findFold'.
 -- If you want to avoid traversing certain directories, use the directory filtering variants like 'findDirFilter'
+
 module Shelly.Find
   ( find
   , findWhen
@@ -13,10 +15,11 @@ module Shelly.Find
   )
 where
 
-import           Prelude                 hiding ( FilePath )
 import           Shelly.Base
 import           Control.Monad                  ( foldM )
+#if !MIN_VERSION_base(4,13,0)
 import           Data.Monoid                    ( mappend )
+#endif
 import           System.PosixCompat.Files       ( getSymbolicLinkStatus
                                                 , isSymbolicLink
                                                 )
@@ -40,14 +43,14 @@ findFold :: (a -> FilePath -> Sh a) -> a -> FilePath -> Sh a
 findFold folder startValue =
   findFoldDirFilter folder startValue (const $ return True)
 
--- | 'find' that filters out directories as it finds
+-- | 'find' that filters out directories as it finds.
 -- Filtering out directories can make a find much more efficient by avoiding entire trees of files.
 findDirFilter :: (FilePath -> Sh Bool) -> FilePath -> Sh [FilePath]
 findDirFilter filt = findDirFilterWhen filt (const $ return True)
 
--- | similar 'findWhen', but also filter out directories
--- Alternatively, similar to 'findDirFilter', but also filter out files
--- Filtering out directories makes the find much more efficient
+-- | Similar to 'findWhen', but also filter out directories.
+-- Alternatively, similar to 'findDirFilter', but also filter out files.
+-- Filtering out directories makes the find much more efficient.
 findDirFilterWhen
   :: (FilePath -> Sh Bool) -- ^ directory filter
   -> (FilePath -> Sh Bool) -- ^ file filter
@@ -59,23 +62,22 @@ findDirFilterWhen dirFilt fileFilter = findFoldDirFilter filterIt [] dirFilt
     yes <- fileFilter fp
     return $ if yes then paths ++ [fp] else paths
 
--- | like 'findDirFilterWhen' but use a folding function rather than a filter
--- The most general finder: you likely want a more specific one
+-- | Like 'findDirFilterWhen' but use a folding function rather than a filter.
+-- The most general finder: you likely want a more specific one.
 findFoldDirFilter
   :: (a -> FilePath -> Sh a) -> a -> (FilePath -> Sh Bool) -> FilePath -> Sh a
 findFoldDirFilter folder startValue dirFilter dir = do
   absDir <- absPath dir
   trace ("find " `mappend` toTextIgnore absDir)
-  files <- ls absDir
   filt <- dirFilter absDir
   if not filt
     then return startValue
     -- use possible relative path, not absolute so that listing will remain relative
     else do
       (rPaths, aPaths) <- lsRelAbs dir
-      foldM traverse startValue (zip rPaths aPaths)
+      foldM traverse' startValue (zip rPaths aPaths)
  where
-  traverse acc (relativePath, absolutePath) = do
+  traverse' acc (relativePath, absolutePath) = do
     -- optimization: don't use Shelly API since our path is already good
     isDir  <- liftIO $ doesDirectoryExist absolutePath
     sym    <- liftIO $ fmap isSymbolicLink $ getSymbolicLinkStatus absolutePath
