@@ -2,11 +2,6 @@
 module EnvSpec ( envSpec ) where
 
 import TestInit
-#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ < 706
-import Prelude hiding ( FilePath, catch)
-#else
-import Prelude hiding ( FilePath)
-#endif
 import Data.Maybe
 
 envSpec :: Spec
@@ -32,7 +27,7 @@ envSpec = do
         setenv "SHELLY" "test"
         get_env_text "SHELLY"
       assert $ res == "test"
- 
+
   describe "get_env \"PATH\" (OS compatibility test)" $ do
     it "get_env" $ do
       res <- shelly $ get_env "PATH"
